/**********************************************************************/
/*                                                                    */
/* This program may be used, executed, copied, modified and           */
/* distributed without royalty for the purpose of developing, using,  */
/* marketing, or distributing.                                        */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* DESCRIPTION:                                                       */
/*                                                                    */
/**********************************************************************/

package com.ibm.activity.reference;

import javax.activity.*;
import javax.activity.coordination.*;


/**
  * The ChildCompleteSignalSet class is the implementation of the
  * org.omg.CosActivity.ChildLifetime signal set that is one of the signal sets
  * that must be supplied by a CORBA or J2EE compliant Activity
  * Service.
  *
  * The ChildComplete signal set is driven on the parent coordinator
  * when a child activity is ended. This occurs after the
  * completion SignalSet has finished producing Signals but before
  * the Synchronization postComplete Signal has been sent.
  *  The child Activity is active is on the thread.
  *
  * The ChildCompleteSignalSet produces the following signal:
  * childComplete - the recipient (an Action registered with the parent
  *              coordinator) is informed that the child activity has
  *              completed. The child activity's completion status and its
  *              identity are encoded within the Signal via the
  *              ActivityInformation class.
  */
final class ChildCompleteSignalSet
   implements javax.activity.coordination.SubordinateSignalSet
   {
   private LocalActivityContext  _context = null;
   private ThreadContextManager  _tcm     = null;
   private String      _signalSetName     = "org.omg.CosActivity.ChildLifetime";
   private String         _signalName     = "childComplete";

   public ChildCompleteSignalSet ()
      {
      Trace.entry ("ChildCompleteSignalSet");
      Trace.exit ("ChildCompleteSignalSet");
      } // end ChildCompleteSignalSet c'tor

   public void   setContext (LocalActivityContext  ctx)
      {
      Trace.entry ("ChildCompleteSignalSet.setContext", ctx);
      _context = ctx;
      Trace.exit ("ChildCompleteSignalSet.setContext");
      }

   public String getSignalSetName ()
      {
      Trace.entry ("ChildCompleteSignalSet.getSignalSetName");
      Trace.exit ("ChildCompleteSignalSet.getSignalSetName", _signalSetName);

      return _signalSetName;
      }  // end ChildCompleteSignalSet.getSignalSetName

 /**
   * Signals produced by a supplied signal set must create an
   * {@link com.ibm.ws.javax.activity.ActivityInformation ActivityInformation}
   * object, containing the activity's
   * {@link com.ibm.ws.javax.activity.GlobalId GlobalId}
   * and {@link com.ibm.ws.javax.activity.CompletionStatus CompletionStatus}.
   */
   public Signal getSignal ()
      {
      Trace.entry ("ChildCompleteSignalSet.getSignal");

      int      compStatus = CompletionStatus.CompletionStatusFail;
      GlobalId   globalId = null;
      if (_context != null)
         {
         // get global id
         globalId   = _context.getGlobalId ();
         compStatus = _context.getCompletionStatus ();
         }  // end if

      Signal sig = new Signal (_signalName, _signalSetName,
         new ActivityInformation (globalId, compStatus));

      Trace.exit ("ChildCompleteSignalSet.getSignal", sig);
      return sig;
      }  // end ChildCompleteSignalSet.getSignal


   public void setSignal (Signal signal)
      {
      Trace.entry ("ChildCompleteSignalSet.setSignal", signal);
      // no implementation necessary
      Trace.exit ("ChildCompleteSignalSet.setSignal");
      }  // end ChildCompleteSignalSet.setSignal

   public CoordinationInformation setResponse (Outcome response) throws
      SignalSetInactiveException
      {
      Trace.entry ("ChildCompleteSignalSet.setResponse", response);
      // no implementation necessary
      Trace.exit ("ChildCompleteSignalSet.setResponse");
      return null;
      }  // end ChildCompleteSignalSet.setResponse

   public Outcome getOutcome () throws SignalSetActiveException
      {
      Trace.entry ("ChildCompleteSignalSet.getOutcome");
      // no implementation necessary
      Trace.exit ("ChildCompleteSignalSet.getOutcome");
      return null;
      }  // end ChildCompleteSignalSet.getOutcome

   public Outcome getCurrentOutcome ()
      {
      Trace.entry ("ChildCompleteSignalSet.getCurrentOutcome");
      // no implementation necessary
      Trace.exit ("ChildCompleteSignalSet.getCurrentOutcome");
      return null;
      }  // end ChildCompleteSignalSet.getCurrentOutcome

   public void setCompletionStatus (int completionStatus, int status)
      {
      Trace.entry ("ChildCompleteSignalSet.setCompletionStatus",
         new Integer (completionStatus));
      // no implementation necessary
      Trace.exit ("ChildCompleteSignalSet.setCompletionStatus");
      }  // end ChildCompleteSignalSet.setCompletionStatus

   public int getCompletionStatus () throws SignalSetActiveException
      {
      Trace.entry ("ChildCompleteSignalSet.getCompletionStatus");
      Trace.exit ("ChildCompleteSignalSet.getCompletionStatus");
      return 0;
      }  // end ChildCompleteSignalSet.getCompletionStatus

   public void destroy ()
      {
      Trace.entry ("ChildCompleteSignalSet.destroy");
      Trace.exit ("ChildCompleteSignalSet.destroy");
      }  // end ChildCompleteSignalSet.destroy

   public void setActivityCoordinator (ActivityCoordinator coord)
      throws SignalSetActiveException
      {
      Trace.entry ("ChildCompleteSignalSet.setActivityCoordinator");
      Trace.exit ("ChildCompleteSignalSet.setActivityCoordinator");
      }  // end ChildCompleteSignalSet.setActivityCoordinator

   }  // end class ChildCompleteSignalSet
