/**********************************************************************/
/*                                                                    */
/* This program may be used, executed, copied, modified and           */
/* distributed without royalty for the purpose of developing, using,  */
/* marketing, or distributing.                                        */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* DESCRIPTION:                                                       */
/*                                                                    */
/**********************************************************************/

package com.ibm.activity.reference;

import javax.activity.*;
import javax.activity.coordination.*;

/**
 * This is the imlementation of the
 * {@link javax.activity.GlobalId GlobalId}
 * interface.  This class is a form of unique identifier for Activity.
 * These objects are immutable.
 */

final class GlobalIdImpl implements GlobalId
   {
   /**
    * The internal representation of GlobalId as a byte array
    */
   private byte []     _gid = null;

   /**
    * initialise the object and build a unique byte array using
    * IP address, timestamp, process id, random number and sequence number
    */
   public GlobalIdImpl ()
      {
      Trace.entry ("GlobalIdImpl.GlobalIdImpl");
      // get IP address
      byte[] IP = null;
      try {
         java.net.InetAddress.getLocalHost ().getAddress ();
         }
      catch (Exception e)
         {
         // add a trace point
         Trace.exception ("GlobalIdImpl: Failed to get IP address", e);
         }

      // get process id
      //  ???? ... or just use a random number
      int rnd = new java.util.Random ().nextInt ();

      // get timestamp
      long ts = System.currentTimeMillis ();

      // get sequence number
      // (long)  seq++;   ... may need to synchronize ????
      //

      // convert to bytes and store
      // ... concatenate subfields as String (stringbuffer?) then use getBytes
      _gid = new StringBuffer().append (IP)
         .append (rnd).append (ts).toString ().getBytes ();
      Trace.exit ("GlobalIdImpl.GlobalIdImpl");
      }  // end c'tor

   /**
    * initialise the object from an <i>imported</i> byte array
    * representation of the object
    */
   public GlobalIdImpl (byte [] b)
      {
      Trace.entry ("GlobalIdImpl.GlobalIdImpl", b);
      _gid = b;
      Trace.exit ("GlobalIdImpl.GlobalIdImpl");
      }  // end c'tor

   // probably need a 'hashCode' method to support hashtable of
   // contexts keyed on GlobalId ????
   // public int hashCode ()  {//convert to string and use string hashcode?}
   //
   // maybe a 'equals' too?
   // public boolean equals (Object obj)

   /**
    * Return a String
    * representation of the object
    * @return byte array converted to String
    */
   public String toString ()
      {
      Trace.entry ("GlobalIdImpl.toString");
      String  result = new String (_gid);
      Trace.exit ("GlobalIdImpl.toString", result);
      return result;
      }  // end toString

   public boolean equals (Object obj)
      {
      Trace.entry ("GlobalIdImpl.equals");
      boolean result = false;
      if (obj != null && obj instanceof GlobalId)
         result =  isEqual((GlobalId) obj);
      Trace.exit ("GlobalIdImpl.equals");
      return result;
      }

// *****************************************************
//
// INTERFACE methods from GlobalId interface
//
// *****************************************************

   public byte[] toBytes()
      {
      Trace.entry ("GlobalIdImpl.toBytes");
      Trace.exit ("GlobalIdImpl.toBytes", _gid);
      return _gid;
      }  // end toBytes


   public String print ()
      {
      Trace.entry ("GlobalIdImpl.print");
      Trace.exit ("GlobalIdImpl.print", _gid);
      return new String (_gid);
      }  // end print

   public boolean isEqual(GlobalId gid)
      {
      Trace.entry ("GlobalIdImpl.isEqual");

      // check gid instanceof GlobalIdImpl !!!
      boolean result = false;
      if (gid != null && gid instanceof GlobalIdImpl)
         {
         GlobalIdImpl  other = (GlobalIdImpl) gid;
         if (this == other)
            {
            result = true;
            Trace.exit ("GlobalIdImpl.isEqual", new Boolean (result));
            return result;
            }  // end if

         if (_gid.length == other._gid.length)
            {
            result = true;
            for (int i = 0; i < _gid.length; i++)
               {
               if (_gid [i] != other._gid [i])
                  {
                  result = false;
                  break;
                  }  // end if

               }  // end for

            }  // end if

         }   // end if

      Trace.exit ("GlobalIdImpl.isEqual", new Boolean (result));
      return result;
      }  // end isEqual

   }  // end class GlobalIdImpl
