package javax.activity;

/**
 * The ActivityInformation class is provided by the Activity service 
 * to assist an {@link javax.activity.coordination.Action Action} that has registered
 * interest with a system {@link javax.activity.coordination.SignalSet SignalSet} to extract the
 * information from <code>Signals</code> produced by that <code>SignalSet</code>. Such <code>Signals</code> contain 
 * an <code>org.omg.CosActivity.ActivityInformation</code> structure encoded in an <code>org.omg.CORBA.Any</code>.
 * The <code>org.omg.CosActivity.ActivityInformation</code> structure is defined in the OMG Activity
 * service specification and consists of a <code>GlobalId</code>, <code>CompletionStatus</code> and <code>Outcome</code>.
 * <br><code>javax.activity.ActivityInformation</code> extends <code>java.io.Serializable</code> and so an
 * instance of this interface may be obtained from a system Signal (such as <code>preCompletion</code>)
 * via its {@link javax.activity.Signal#getExtendedValue getExtendedValue} method.
 */                                                                          
public class ActivityInformation implements java.io.Serializable
{
   /**
    * Constructs an <code>ActivityInformation</code> object, describing the Activity,
    * from the <code>GlobalId</code> and <code>CompletionStatus</code>.
    * The final <code>Outcome</code> of an <code>ActivityInformation</code> object so contructed is <code>nil</code>.
    * An object of this type is encoded in the <code>extendedData</code> of
    * <code>Signals</code> sent by the predefined system <code>SignalSets</code>.
    */                                                                          
   public ActivityInformation(javax.activity.GlobalId globalId, int completionStatus)
   {
      _globalId = globalId;
      _completionStatus = completionStatus;
   }

  /**
    * Constructs an <code>ActivityInformation</code> object, describing the Activity,
    * from the <code>GlobalId</code>, <code>CompletionStatus</code> and final
    * <code>Outcome</code>.
    * An object of this type is encoded in the <code>extendedData</code> of
    * the <code>postComplete</code> signal sent by the system <code>SynchronizationSignalSet</code>.
    */                                                                          
   public ActivityInformation(javax.activity.GlobalId globalId, int completionStatus, Outcome finalOutcome)
   {
      _globalId = globalId;
      _completionStatus = completionStatus;
      _outcome = finalOutcome;
   }

   /**
    * Returns the <code>GlobalId</code> contained within the <code>ActivityInformation</code>.
    *
    * @return The {@link javax.activity.GlobalId GlobalId}
    *         of the Activity within which context the <code>Signal</code> was sent.
    */                                                                          
   public GlobalId getGlobalId()
   {
     return _globalId;
   }
                         
   /**
    * Returns the <code>CompletionStatus</code> contained within the <code>ActivityInformation</code>.
    *
    * @return The {@link javax.activity.CompletionStatus CompletionStatus}
    *         of the Activity within which context the <code>Signal</code> was sent.
    */                                                                          
   public int getCompletionStatus()
   {
     return _completionStatus;
   }
   
   /**
    * Returns the <code>Outcome</code> contained within the <code>ActivityInformation</code>.
    *
    * @return The {@link javax.activity.Outcome Outcome}
    *         of the Activity within which context the <code>Signal</code> was sent.
    */
   public Outcome getFinalOutcome()
   {
     return _outcome;
   }
   
   // Private attributes
   private GlobalId _globalId = null;
   private int _completionStatus = CompletionStatus.CompletionStatusSuccess;  
   private Outcome _outcome = null;
}
