package javax.activity;

/**
 * When an Activity completes, it does so in one of two states, either <code>success</code> or       
 * <code>failure</code>. The <code>success</code> state is represented by a CompletionStatus               
 * value of <code>CompletionStatusSuccess</code>. The <code>failure</code> state is represented by         
 * one of two CompletionStatus values: <code>CompletionStatusFail</code> and                         
 * <code>CompletionStatusFailOnly</code>.                                                            
 * <br>During its lifetime, the completion state of the Activity (i.e., the state it           
 * would have if it completed at that point) may change from <code>success</code> to <code>failure</code>, 
 * and back again many times. If the CompletionStatus is set to CompletionStatusFailOnly,      
 * however, the completion state is latched to <code>failure</code>.                                 
 * <br>The CompletionStatus may affect the signals that are produced by the CompletionSignalSet
 * during Activity completion; the specific effect is a detail of the CompletionSignalSet      
 * behaviour.                                                                                  
 * 
 */
public interface CompletionStatus
{

   /**
    * The Activity has successfully performed its work and can complete
    * accordingly. When in this state, the Activity CompletionStatus
    * can be changed.
    */
   public final static int CompletionStatusSuccess = 0;
   /**
    * The Activity has not successfully completed its work, either as
    * a result of application failure or simply due to processing that
    * is not yet complete, and should be driven accordingly during
    * completion. When in this state, the Activity CompletionStatus
    * can be changed. This is the initial CompletionStatus of an Activity.
    */
   public final static int CompletionStatusFail = 1;
   /**
    * The Activity has not successfully completed its work, as a result
    * of a system or application failure, and should be driven accordingly
    * during completion. When in this state, the Activity CompletionStatus
    * <b>cannot</b> be changed.
    */
   public final static int CompletionStatusFailOnly = 2;

}
