package javax.activity;

/**
 * This exception is thrown by the Activity service if
 * an attempt is made to retrieve, or otherwise reference, a PropertyGroup
 * with a name for which no <i>PropertyGroupManager</i>
 * has been registered.
 * 
 */
public class PropertyGroupUnknownException extends java.lang.Exception
{
   /**
    * Default constructor for the exception.
    *
    */
   public PropertyGroupUnknownException()
   {
   }
   /**
    * Constructs a PropertyGroupUnknownException with the specified 
    * <i>propertyGroupName</i>.
    *
    */
   public PropertyGroupUnknownException(String propertyGroupName)
   {
      pgName = new String(propertyGroupName);
   }
   /**
    * Retreives the failing <i>propertyGroupName</i>. This method is
    * typically called to determine which propertyGroupName caused a
    * failure when an array of propertyGroupNames has been used as
    * an argument.
    *
    * @return The name of the PropertyGroup, for which there is no registered
    *    PropertyGroupManager, that led to this exception being raised.
    *
    */
   public String getPropertyGroupName()
   {
      return pgName;
   }


   /**
    * Constructs an instance of the exception with the specified
    * <code>propertyGroupName</code> and <code>cause</code>.
    *
    */
   public PropertyGroupUnknownException(String propertyGroupName, Throwable cause)
   {
      pgName = new String(propertyGroupName);
      _expn = cause;
   }

   private Throwable _expn = null;
   private String pgName=null;
}
