package javax.activity.coordination;
import javax.activity.*;

/**
  * An <code>Action</code> is an entity that is registered, via an
  * {@link javax.activity.ActivityCoordinator ActivityCoordinator}, with an interest
  * in one or more {@link javax.activity.coordination.SignalSet SignalSets}. An Action may only be
  *  registered with a single <code>ActivityCoordinator</code>.
  *
  * <br>An <code>Action</code> is the target object to which <code>Signals</code>,
  * produced by a <code>SignalSet</code>, are sent during <code>broadcast</code>
  * and <code>complete</code> operations.
  */                                                                          
public interface Action
{

   /**
    * Invoked on the target object, by the Activity service, during signal processing.
    *
    * @param signal A {@link javax.activity.Signal Signal} produced by a <code>SignalSet</code>.
    *
    * @return An {@link javax.activity.Outcome Outcome} that indicates
    *    the result of the processing of the received Signal by the target Action.
    *
    * @exception ActionErrorException Thrown if the <code>Action</code> encounters
    *    an unexpected error condition during signal processing.
    *    This exception is mapped by the Activity service to the predefined
    *    <code>org.omg.CosActivity.ActionError</code> or
    *    <code>org.omg.CosActivity.ActionSystemException</code> Outcomes.
    *
    */
   public Outcome processSignal(Signal signal) throws ActionErrorException;

   /**
    * Called on the target object, by the Activity service, when the
    * target object is no longer required and indicates to the object
    * that it should perform any necessary clean-up.  
    * The <code>ActivityCoordinator</code> with which the target object was associated 
    * is not available at the time this method is called.  <code>Actions</code> registered 
    * with an interest in the <i>Synchronization</i> <code>SignalSet</code>, such as all global 
    * <code>Actions</code>, do not receive an explicit <code>destroy</code> call but should
    * instead use the <code>postComplete</code> signal as the indication that they will
    * receive no further calls.  
    *
    */
   public void destroy();
}
