package javax.activity.coordination;
import javax.activity.*;

/**
  * A <code>RecoverableAction</code> is an object that encapsulates a registered 
  * {@link javax.activity.coordination.Action Action} and the priority it was registered with.
  * An array of <code>RecoverableActions</code> is returned by a call to the <code>ServiceManager</code>
  * {@link javax.activity.coordination.ServiceManager#recoverActions(GlobalId, String) recoverActions} method.
  * <br>An HLS is responsible for persisting the state required to recreate a <code>RecoverableAction</code>
  * following a failure. 
  */                                                                          
public interface RecoverableAction
{

   /**
    * Returns the Action represented by this object.
    * This is used during the recovery of an Activity following a failure.
    *
    * @return The Action associated with this object.
    *
    */
   public Action getAction();

   /**
    * Returns the priority of the Action within the Activity. 
    * This is typically during recovery to recreate the appropriate priority ordering
    * of a sequence of recovered Actions.
    *
    * @return The priority of the Action within the Activity.
    *
    */
   public int getPriority();

}
