package javax.activity.coordination;
import javax.activity.*;

/**
  * SubordinateSignalSet is a specialization
  * of {@link javax.activity.coordination.SignalSet SignalSet} that
  * is provided by a high-level service (HLS) to be used in a subordinate server.
  * A subordinate server is an application server that is involved in a distributed
  * Activity but does not contain the Activity-originator. The SignalSet on a subordinate
  * sever is responsible for producing a combined <code>Outcome</code> for its server to individual
  * </code>Signals</code> received from a superior server.
  * A superior server may itself be subordinate to another
  * server in a widely distributed Activity. 
  * An HLS may chose to provide distinct SignalSet and SubordinateSignalSet implementations
  * if it is sensitive to whether the execution environment is a subordinate server or the root
  * server for an Activity. An HLS is not required to provide such distinct implementations and a
  * {@link javax.activity.coordination.ServiceManager ServiceManager}
  * may return the same object in response to both 
  * {@link javax.activity.coordination.ServiceManager#getSignalSet(String) getSignalSet} and
  * {@link javax.activity.coordination.ServiceManager#getSubordinateSignalSet(String) getSubordinateSignalSet} 
  * requests from the Activity service.
  */                                                                          
public interface SubordinateSignalSet extends SignalSet
{
   /**
    * Sets the {@link javax.activity.Signal Signal} to be sent to the
    * {@link javax.activity.coordination.Action Actions} registered for this   
    * <code>SignalSet</code>. 
    * This method is called by a subordinate <code>ActivityCoordinator</code>
    * when it receives a <code>Signal</code> from its superior. The subordinate
    * <code>ActivityCoordinator</code> distributes this <code>Signal</code> to each
    * registered <code>Action</code> and passes each Action <code>Outcome</code> back
    * to the <code>SignalSet</code> via the {@link #setResponse(Outcome) setResponse} method.
    * The <code>SignalSet</code> produces a combined <code>Outcome</code> for
    * the <code>Signal</code> and this is returned by the subordinate
    * <code>ActivityCoordinator</code> to its superior.
    * Any system exceptions raised by the <code>SignalSet</code> should be converted to an
    * <i>ActionError</i> <code>Outcome</code> by the subordinate <code>ActivityCoordinator</code>.
    *
    */
   public void setSignal(Signal signal);

   /**
    * Returns an intermediate {@link javax.activity.Outcome Outcome} of the <code>SignalSet</code>.
    * This may be called after the processing of each <code>Signal</code> and is used by
    * a subordinate <code>ActivityCoordinator</code> to obtain a coordinated
    * <code>Outcome</code> to return to
    * its superior in response to a received <code>Signal</code>.
    *
    * @return The intermediate {@link javax.activity.Outcome Outcome} of the <code>SignalSet</code>.
    *    It is valid for the intermediate <code>Outcome</code> to be <code>null</code>.
    *
    * @exception SignalSetInactiveException Thrown if an <code>Outcome</code> is requested
    *    without there first having been a call to the <code>SubordinateSignalSet</code>
    *    {@link #setSignal(Signal) setSignal} method.
    */
   public Outcome getCurrentOutcome() throws SignalSetInactiveException;


}
