package javax.activity.propertygroup;
import javax.activity.*;

/**
  * A <code>PropertyGroup</code> is used to provide distributed context, scoped to
  * an Activity, that may be set by an application or a high-level service (HLS)
  * built on top of the Activity service. The format of the distributed
  * context is specific to the <code>PropertyGroup</code> implementation and is neither
  * examined nor understood by the Activity service. The semantics of the
  * behavioural relationship between PropertyGroups in nested Activities
  * is defined by the specification of
  * each type of PropertyGroup and not by the Activity service. 
  * <br>Any number of named <code>PropertyGroup</code> types may be registered with
  * the Activity service. When an Activity is started, an instance of
  * each type of <code>PropertyGroup</code> used by the Activity is created and associated
  * with the Activity. The types of <code>PropertyGroup</code> used by an Activity
  * may be specified through the {@link javax.activity.coordination.ServiceManager ServiceManager}
  * object registered for a particular HLS.
  * 
  */                                                                          
public interface PropertyGroup
{
   /**
    * Returns the name of the target <code>PropertyGroup</code>.
    *
    * @return the name of the target <code>PropertyGroup</code>.
    *
    */
   public String getPropertyGroupName();

   /**
    * Called by the Activity service as part of its completion processing to 
    * give the <code>PropertyGroup</code> the opportunity to perform any necessary clean-up 
    * work.  The Activity with which this <code>PropertyGroup</code> is associated is not 
    * active on the thread when this call is made.  Any parent Activity will 
    * be active on the thread.
    *
    */
   public void completed();

   /**
    * Called to inform the <code>PropertyGroup</code> that the Activity it 
    * represents has been suspended.  The Activity with which this <code>PropertyGroup</code> 
    * is associated is still active on the thread when this call is made, but 
    * will be removed immediately after all <code>suspended</code> methods of registered 
    * <code>PropertyGroups</code> have been called.  Any parent Activity will then become 
    * active.  
    */
   public void suspended();

   /**
    * Called to inform the <code>PropertyGroup</code> that the Activity it                    
    * represents has been resumed.  The Activity with which this <code>PropertyGroup</code>   
    * is associated is already resumed on the thread when this call is made.                 
    */
   public void resumed();
}
